@@ -1,6 +1,6 @@
 class Reddit:
     def __init__(self, content, title, upvote_ratio,
-                 total_awards, score, downvotes, created_at, nsfw, pinned, author, post_url, stickied, spoiler,
+                 total_awards, score, downvotes, created_at, nsfw, author, post_url, stickied, spoiler,
                  post_flair, author_flair, subreddit_subscribers):
         self.content = content
         self.title = title
@@ -10,7 +10,6 @@ class Reddit:
         self.downvotes = downvotes
         self.created_at = created_at
         self.nsfw = nsfw
-        self.pinned = pinned
         self.author = author
         self.post_url = post_url
         self.stickied = stickied
